#Requires -Version 5.1
#Requires -Modules @{ ModuleName="Az.Accounts"; RequiredVersion="2.13.0" }
#Requires -Modules @{ ModuleName="Az.Websites"; RequiredVersion="3.1.1" }

Param(
    [Parameter(Mandatory = $true)] 
    [ValidateNotNull()]
    [string] 
    $TenantId,

    [Parameter(Mandatory = $true)] 
    [ValidateNotNull()]
    [string] 
    $SubscriptionId,

    [Parameter(Mandatory = $true)] 
    [ValidateNotNull()]
    [string] 
    $AppServiceName,

    [Parameter(Mandatory = $true)] 
    [ValidateNotNull()]
    [string] 
    $ApplicationId,

    [Parameter(ParameterSetName = 'AppRegistrationTenantId')] 
    [ValidateNotNull()]
    [string]
    $AppRegistrationTenantId,

    [Parameter(Mandatory = $true)] 
    [ValidateNotNull()]
    [string]
    $ClientSecret,

    [Parameter(Mandatory = $false)]
    [ValidateNotNull()]
    [bool] 
    $UseCurrentAzContext = $false,
    
    [ValidateSet("AzureCloud", "AzureUsGovernment", "AzureGermanCloud", "AzureChinaCloud")] 
    [string] 
    $Environment = "AzureCloud"
)

#####################################################################
# Connect to Azure
#####################################################################
Write-Progress -Activity "Initializing App Service" -Id 4 -Status "Checking Azure context" -PercentComplete 25
$AzContext = Get-AzContext
if($UseCurrentAzContext -eq $false -or $null -eq $AzContext -or $AzContext.Tenant.Id -ne $TenantId -or $AzContext.Subscription.Id -ne $SubscriptionId) {
    Connect-AzAccount -TenantId $TenantId -SubscriptionId $SubscriptionId -Environment $Environment 
}

#####################################################################
# Configuration
#####################################################################
Write-Progress -Activity "Initializing App Service" -Id 4 -Status "Configuring app service" -PercentComplete 50
$App = Get-AzWebApp -Name $AppServiceName

$AppSettings = @{}

if ($AppRegistrationTenantId) {
    $AppSettings.add('AzureAd:TenantId', $AppRegistrationTenantId)
}
else {
    $AppSettings.add('AzureAd:TenantId', $TenantId)
}

$AppSettings.add("AzureAd:ClientId", $ApplicationId)
$AppSettings.add("AzureAd:ClientSecret", $ClientSecret)

foreach ($setting in $app.SiteConfig.AppSettings)
{
    $AppSettings.add($setting.Name, $setting.Value)
}

Write-Progress -Activity "Initializing App Service" -Id 4 -Status "Updating app service" -PercentComplete 75
Set-AzWebApp -AppSettings $AppSettings -Name $AppServiceName -ResourceGroupName $App.ResourceGroup

#####################################################################
# Output
#####################################################################
Write-Progress -Activity "Initializing App Service" -Id 4 -Status "Preparing output" -PercentComplete 95
Write-Output @{
    ConnectionString = $($App.SiteConfig.ConnectionStrings.ConnectionString)
}

Write-Progress -Activity "Initializing App Service" -Id 4 -Status "Complete" -PercentComplete 100

Exit 0